#include <QtDBus/QtDBus>

#include "debug.h"
#include "bluetoothavrcpadapter.h"

BluetoothAVRCPAdapter::BluetoothAVRCPAdapter(QObject *parent) :
    QObject(parent),
    deviceConnected_(false)
{
    // org.bluez.Control is the interface that shows up as soon as the
    // AVRCP device connects
    if (!QDBusConnection::systemBus().connect("", "", "org.bluez.Control", "Connected", this, SLOT(handleControlConnected())))
        qWarning("Cannot connect to org.bluez.Control::Connected signal.");

    if (!QDBusConnection::systemBus().connect("", "", "org.bluez.Control", "Disconnected", this, SLOT(handleControlDisconnected())))
        qWarning("Cannot connect to org.bluez.Control::Disconnected signal.");

    // bluez creates a logial input device once org.bluez.Control is connected...
    if (!QDBusConnection::systemBus().connect("", "",
        "org.freedesktop.Hal.Device", "Condition",
        this, SLOT(handleInputDeviceConditionSignal(QString, QString))))
        qWarning("Cannot connect to org.freedesktop.Hal.Device::Condition signal.");
}

void BluetoothAVRCPAdapter::handleControlConnected()
{
    DGUARDMETHOD;
    if (deviceConnected_)
        return;

    deviceConnected_ = true;
    emit connected();
}

void BluetoothAVRCPAdapter::handleControlDisconnected()
{
    DGUARDMETHOD;
    if (!deviceConnected_)
        return;

    deviceConnected_ = false;
    emit disconnected();
}

void BluetoothAVRCPAdapter::handleInputDeviceConditionSignal(QString event, QString state)
{
    DGUARDMETHOD;
    DPRINTF("event: %s, state: %s", (const char*)event.toUtf8(), (const char*)state.toUtf8());

    if (event == "ButtonPressed")
    {
        if (state == "play-cd" ||
            state == "pause-cd")
            emit playOrPause();
        else if (state == "stop-cd")
            emit stop();
        else if (state == "previous-song")
            emit previous();
        else if (state == "next-song")
            emit next();
    }
}
